@@ -2,4 +2,4 @@ utils::globalVariables(c('value','analysisId','id','level','resultsByGroup','gro
                          'referencedOperationRelationshipId','operationId','description',
                          'referencedOperationRole','outputId','condition_dataset','condition_variable',
                          'condition_comparator','condition_value','label','groupingVariable','name',
-                         'compoundExpression_logicalOperator','rFilt_1','rFilt_2'))
+                         'compoundExpression_logicalOperator','rFilt_1','rFilt_2', 'dataset', 'ADaM_folder'))
